(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      8334,        274]
NotebookOptionsPosition[      7301,        237]
NotebookOutlinePosition[      7576,        251]
CellTagsIndexPosition[      7533,        248]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Visualizing Earthquake Data", "Subtitle"],

Cell["\<\
USGS/NEIC (PDE) 1 Jan 2004 to 27 Jun 2005. 
Data from: http://neic.usgs.gov/neis/epic/epic_global.html\
\>", "Text"],

Cell["First, we import the data.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"ToFileName", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\"\<FileName\>\"", "/.", 
       RowBox[{"NotebookInformation", "[", 
        RowBox[{"EvaluationNotebook", "[", "]"}], "]"}]}], ")"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Import", "[", "\"\<quake4.csv\>\"", "]"}]}], ";"}]], "Input"],

Cell["\<\
Next, we construct a working dataset comprised of only the fields we are \
interested in.  In this case, the latitude, longitude, magnitude, and depth.  \
To expression is used here to force blank fields to become Null entries.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"newdata", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ToExpression", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "5"}], "]"}], "]"}], ",", 
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "6"}], "]"}], "]"}], ",", 
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "7"}], "]"}], "]"}], ",", 
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "8"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "data", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell["\<\
A few entries contain letters.  For the purposes here, we only want numeric \
entries.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"finaldata", "=", 
   RowBox[{"Cases", "[", 
    RowBox[{"newdata", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"lat_", "?", "NumericQ"}], ",", 
       RowBox[{"lon_", "?", "NumericQ"}], ",", 
       RowBox[{"mag_", "?", "NumericQ"}], ",", 
       RowBox[{"dep_", "?", "NumericQ"}]}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell["\<\
It is useful to overlay the data with the continents for geographic \
reference.  The WorldPlot package can be used here.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"<<", "Miscellaneous`WorldPlot`"}]], "Input"],

Cell["\<\
We want to extract the Graphics primitives for later use.  For this reason, \
the WorldPlot object is converted into a Graphics object.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"initmap", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"WorldPlot", "[", 
     RowBox[{"World", ",", 
      RowBox[{"WorldGrid", "\[Rule]", "None"}], ",", 
      RowBox[{"Axes", "\[Rule]", "False"}], ",", 
      RowBox[{"WorldFrame", "\[Rule]", "None"}]}], "]"}], "]"}]}], 
  ";"}]], "Input"],

Cell["\<\
Here, we extract the polygons and convert them to Line primitives.  This way, \
we only see the outline of the continents and countries, rather than filled \
polygons that might block our view.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"unscaledmap", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cases", "[", 
      RowBox[{
       RowBox[{"initmap", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"Polygon", "[", "___", "]"}], ",", "Infinity"}], "]"}], "/.", 
     RowBox[{
      RowBox[{"Polygon", "[", "x__", "]"}], "\[Rule]", 
      RowBox[{"Line", "[", "x", "]"}]}]}], ")"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["2D", "Section"],

Cell["\<\
Now, we can start manipulating the data.  First, we replace and transform all \
4-tuples in the dataset into the appropriate Graphics directives and \
primitives.  This includes size and color values.   The PointSize is \
arbitrarily scaled for visual effect.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"grdata2D", "=", 
   RowBox[{"finaldata", "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"lat_", ",", "lon_", ",", "mag_", ",", "dep_"}], "}"}], 
     "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", 
        RowBox[{
         RowBox[{"mag", "^", "2.7"}], "/", "6000"}], "]"}], ",", 
       RowBox[{"Hue", "[", 
        RowBox[{".8", "-", 
         RowBox[{".8", " ", 
          RowBox[{"mag", "/", "10"}]}]}], "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{"{", 
         RowBox[{"lon", ",", "lat"}], "}"}], "]"}]}], "}"}]}]}]}], 
  ";"}]], "Input"],

Cell["\<\
The original map graphic needs to be rescaled so that all of the vertices \
conform to latitude and longitude ranges.  The following rescales every pair \
of points to the appropriate ranges.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"map2d", "=", 
   RowBox[{"unscaledmap", "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x_", "?", "NumberQ"}], ",", 
       RowBox[{"y_", "?", "NumberQ"}]}], "}"}], "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Rescale", "[", 
        RowBox[{"x", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "11000"}], ",", "11000"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "180"}], ",", "180"}], "}"}]}], "]"}], ",", 
       RowBox[{"Rescale", "[", 
        RowBox[{"y", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "5000"}], ",", "5000"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "90"}], ",", "90"}], "}"}]}], "]"}]}], "}"}]}]}]}], 
  ";"}]], "Input"],

Cell["\<\
Now, we can combine the map and the data.  The result visually demonstrates \
that most of the earthquakes occur along the continental plate boundaries.  \
Most of the quakes are blue or green and are small to medium in size.  Large \
quakes are less frequent, but this dataset includes at least two large \
quakes, including the destrcutive Sumatra earthquake that occurred in \
December of 2004.  Earthquakes are so common in this area that the \
predominance of the smaller quakes nearly obscures the location of the large \
quake shown as an orange spot.  Close examination also shows another large \
quake southeast of Australia.   \
\>", "Text"],

Cell[BoxData[
 RowBox[{"myout2d", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"map2d", ",", 
       RowBox[{"Take", "[", 
        RowBox[{"grdata2D", ",", " ", 
         RowBox[{"{", 
          RowBox[{"1", ",", "40308", ",", "4"}], "}"}]}], "]"}]}], "}"}], 
     "]"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}]], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"6.0 for Macintosh",
WindowSize->{764, 510},
WindowMargins->{{12, Automatic}, {Automatic, 0}}
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 47, 0, 46, "Subtitle"],
Cell[640, 25, 126, 3, 41, "Text"],
Cell[769, 30, 42, 0, 26, "Text"],
Cell[814, 32, 343, 9, 24, "Input"],
Cell[1160, 43, 121, 3, 24, "Input"],
Cell[1284, 48, 251, 4, 41, "Text"],
Cell[1538, 54, 747, 23, 39, "Input"],
Cell[2288, 79, 110, 3, 26, "Text"],
Cell[2401, 84, 364, 10, 24, "Input"],
Cell[2768, 96, 145, 3, 26, "Text"],
Cell[2916, 101, 68, 1, 24, "Input"],
Cell[2987, 104, 159, 3, 26, "Text"],
Cell[3149, 109, 329, 9, 24, "Input"],
Cell[3481, 120, 217, 4, 41, "Text"],
Cell[3701, 126, 422, 12, 24, "Input"],
Cell[CellGroupData[{
Cell[4148, 142, 21, 0, 67, "Section"],
Cell[4172, 144, 283, 5, 41, "Text"],
Cell[4458, 151, 632, 20, 54, "Input"],
Cell[5093, 173, 215, 4, 41, "Text"],
Cell[5311, 179, 844, 27, 54, "Input"],
Cell[6158, 208, 661, 10, 86, "Text"],
Cell[6822, 220, 451, 13, 39, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

